==> sso-common-2.3.18-sources.jar: cn/com/duiba/sso/api/service/export/SsoExportFileService.java <==
package cn.com.duiba.sso.api.service.export;

import cn.com.duiba.sso.api.exception.SsoRunTimeException;
import com.google.common.base.Joiner;
import org.springframework.beans.BeansException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.data.redis.core.BoundHashOperations;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import java.io.File;
import java.util.Map;
import java.util.concurrent.ExecutorService;

@Service
public class SsoExportFileService implements ApplicationContextAware {

    private static final String EXPORT_FILE_TESK_NAME = "EXPORT_FILE_TESK_NAME";

    private static final Joiner KEY_JOINER = Joiner.on("_").skipNulls();

    private ApplicationContext applicationContext;

    private static final String FILE_PATH = "tempFiles/";

    @Autowired(required = false)
    private StringRedisTemplate stringRedisTemplate;

    protected StringRedisTemplate getStringRedisTemplate() {
        return stringRedisTemplate;
    }

    @Autowired
    private ExecutorService executorService;

    public ExportFileInfo getExportFileInfo(Long taskId){
        String key = getTaskKey(taskId);
        if(stringRedisTemplate==null){
            throw new SsoRunTimeException("需要往SsoExportFileService中setStringRedisTemplate才能使用此功能");
        }
        ExportFileInfo info = new ExportFileInfo();
        if(!stringRedisTemplate.hasKey(key)){
            return info;
        }
        BoundHashOperations<String,String,String> operations = stringRedisTemplate.boundHashOps(key);
        Map<String,String> map = operations.entries();
        info.setTaskId(taskId);
        info.setMessage(map.get("message"));
        info.setCount(Integer.valueOf(map.get("count")));
        info.setSuccessCount(Integer.valueOf(map.get("successCount")));
        info.setFileName(map.get("fileName"));
        info.setSuccess(Boolean.valueOf(map.get("success")));
        info.setUrl(map.get("url"));
        return info;
    }

    public <T extends BaseExportRunnable> T createExportTask(Class<T> teskType){
        if(stringRedisTemplate==null){
            throw new SsoRunTimeException("需要往SsoExportFileService中setStringRedisTemplate才能使用此功能");
        }
        return applicationContext.getBean(teskType);
    }

    public void runTesk(BaseExportRunnable runnable){
        executorService.submit(runnable);
    }


    @Override
    public void setApplicationContext(ApplicationContext applicationContext) throws BeansException {
        this.applicationContext = applicationContext;
    }

    protected String getTaskKey(Long taskId){
        return KEY_JOINER.join(EXPORT_FILE_TESK_NAME,taskId);
    }


    public File getTempDir(){
        String webRootDir = System.getProperty("user.home");
        File userDir = new File(webRootDir,FILE_PATH);
        if (!userDir.exists()) {
            userDir.mkdirs();
        }
        return userDir;
    }



}

==> sso-common-2.3.47-sources.jar: cn/com/duiba/sso/api/service/export/SsoExportFileService.java <==
package cn.com.duiba.sso.api.service.export;

import cn.com.duiba.sso.api.exception.SsoRunTimeException;
import com.google.common.base.Joiner;
import org.springframework.beans.BeansException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.data.redis.core.BoundHashOperations;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import java.io.File;
import java.util.Map;
import java.util.concurrent.ExecutorService;

@Service
public class SsoExportFileService{

    private static final String EXPORT_FILE_TESK_NAME = "EXPORT_FILE_TESK_NAME";

    private static final Joiner KEY_JOINER = Joiner.on("_").skipNulls();

    @Autowired
    private ApplicationContext applicationContext;

    private static final String FILE_PATH = "tempFiles/";

    @Autowired(required = false)
    private StringRedisTemplate stringRedisTemplate;

    protected StringRedisTemplate getStringRedisTemplate() {
        return stringRedisTemplate;
    }

    @Autowired
    private ExecutorService executorService;

    public ExportFileInfo getExportFileInfo(Long taskId){
        String key = getTaskKey(taskId);
        if(stringRedisTemplate==null){
            throw new SsoRunTimeException("需要往SsoExportFileService中setStringRedisTemplate才能使用此功能");
        }
        ExportFileInfo info = new ExportFileInfo();
        if(!stringRedisTemplate.hasKey(key)){
            return info;
        }
        BoundHashOperations<String,String,String> operations = stringRedisTemplate.boundHashOps(key);
        Map<String,String> map = operations.entries();
        info.setTaskId(taskId);
        info.setMessage(map.get("message"));
        info.setCount(Integer.valueOf(map.get("count")));
        info.setSuccessCount(Integer.valueOf(map.get("successCount")));
        info.setFileName(map.get("fileName"));
        info.setSuccess(Boolean.valueOf(map.get("success")));
        info.setUrl(map.get("url"));
        return info;
    }

    public <T extends BaseExportRunnable> T createExportTask(Class<T> teskType){
        if(stringRedisTemplate==null){
            throw new SsoRunTimeException("需要往SsoExportFileService中setStringRedisTemplate才能使用此功能");
        }
        return applicationContext.getBean(teskType);
    }

    public void runTesk(BaseExportRunnable runnable){
        executorService.submit(runnable);
    }


    protected String getTaskKey(Long taskId){
        return KEY_JOINER.join(EXPORT_FILE_TESK_NAME,taskId);
    }


    public File getTempDir(){
        String webRootDir = System.getProperty("user.home");
        File userDir = new File(webRootDir,FILE_PATH);
        if (!userDir.exists()) {
            userDir.mkdirs();
        }
        return userDir;
    }



}
